import {isUndefinedOrNull}from'@vscode-alt/monaco-editor/esm/vs/base/common/types.js';import {FileSystemProviderErrorCode}from'../interfaces/files.js';import'../interfaces/textfiles.js';import'../interfaces/error-codes.js';import'../interfaces/generated-models.js';/* tslint:disable */
class FileOperationError extends Error {
  fileOperationResult;
  options;
  constructor(message, fileOperationResult, options) {
    super(message);
    this.fileOperationResult = fileOperationResult;
    this.options = options;
  }
  static isFileOperationError(obj) {
    return obj instanceof Error && !isUndefinedOrNull(obj.fileOperationResult);
  }
}
function hasReadWriteCapability(provider) {
  return !!(provider.capabilities & 2 /* FileSystemProviderCapabilities.FileReadWrite */);
}
function hasFileFolderCopyCapability(provider) {
  return !!(provider.capabilities & 8 /* FileSystemProviderCapabilities.FileFolderCopy */);
}
function hasOpenReadWriteCloseCapability(provider) {
  return !!(provider.capabilities & 4 /* FileSystemProviderCapabilities.FileOpenReadWriteClose */);
}
function etag(stat) {
  if (typeof stat.size !== 'number' || typeof stat.mtime !== 'number') {
    return undefined;
  }
  return stat.mtime.toString(29) + stat.size.toString(31);
}
class FileSystemProviderError extends Error {
  code;
  constructor(message, code) {
    super(message);
    this.code = code;
  }
}
function createFileSystemProviderError(error, code) {
  const providerError = new FileSystemProviderError(error.toString(), code);
  markAsFileSystemProviderError(providerError, code);
  return providerError;
}
function markAsFileSystemProviderError(error, code) {
  error.name = code ? `${code} (FileSystemError)` : `FileSystemError`;
  return error;
}
function toFileSystemProviderErrorCode(error) {
  // Guard against abuse
  if (!error) {
    return FileSystemProviderErrorCode.Unknown;
  }
  // FileSystemProviderError comes with the code
  if (error instanceof FileSystemProviderError) {
    return error.code;
  }
  // Any other error, check for name match by assuming that the error
  // went through the markAsFileSystemProviderError() method
  const match = /^(.+) \(FileSystemError\)$/.exec(error.name);
  if (!match) {
    return FileSystemProviderErrorCode.Unknown;
  }
  switch (match[1]) {
    case FileSystemProviderErrorCode.FileExists:
      return FileSystemProviderErrorCode.FileExists;
    case FileSystemProviderErrorCode.FileIsADirectory:
      return FileSystemProviderErrorCode.FileIsADirectory;
    case FileSystemProviderErrorCode.FileNotADirectory:
      return FileSystemProviderErrorCode.FileNotADirectory;
    case FileSystemProviderErrorCode.FileNotFound:
      return FileSystemProviderErrorCode.FileNotFound;
    case FileSystemProviderErrorCode.NoPermissions:
      return FileSystemProviderErrorCode.NoPermissions;
    case FileSystemProviderErrorCode.Unavailable:
      return FileSystemProviderErrorCode.Unavailable;
  }
  return FileSystemProviderErrorCode.Unknown;
}
function toFileOperationResult(error) {
  // FileSystemProviderError comes with the result already
  if (error instanceof FileOperationError) {
    return error.fileOperationResult;
  }
  // Otherwise try to find from code
  switch (toFileSystemProviderErrorCode(error)) {
    case FileSystemProviderErrorCode.FileNotFound:
      return "FILE_NOT_FOUND" /* FileOperationResult.FILE_NOT_FOUND */;
    case FileSystemProviderErrorCode.FileIsADirectory:
      return "FILE_IS_DIRECTORY" /* FileOperationResult.FILE_IS_DIRECTORY */;
    case FileSystemProviderErrorCode.NoPermissions:
      return "FILE_PERMISSION_DENIED" /* FileOperationResult.FILE_PERMISSION_DENIED */;
    case FileSystemProviderErrorCode.FileExists:
      return "FILE_MOVE_CONFLICT" /* FileOperationResult.FILE_MOVE_CONFLICT */;
    case FileSystemProviderErrorCode.FileNotADirectory:
    default:
      return "FILE_OTHER_ERROR" /* FileOperationResult.FILE_OTHER_ERROR */;
  }
}export{FileOperationError,FileSystemProviderError,createFileSystemProviderError,etag,hasFileFolderCopyCapability,hasOpenReadWriteCloseCapability,hasReadWriteCapability,markAsFileSystemProviderError,toFileOperationResult,toFileSystemProviderErrorCode};//# sourceMappingURL=files.js.map
